@@ -93,14 +93,14 @@ def _create_deb_file(conanfile):
     #### set folder name
     package_name = conanfile.name
     package_version = conanfile.version
-    if not conanfile.deb_install_folder:
-        deb_install_folder = "/sense2"
+    if not conanfile.deb_install_path:
+        deb_install_path = "/sense2"
     else:
-        deb_install_folder = conanfile.deb_install_folder
+        deb_install_path = conanfile.deb_install_path
     deb_folder = package_name
     deb_file = package_name + "_" + package_version + ".deb"
     debian_folder = deb_folder + "/DEBIAN"
-    app_folder = deb_folder + deb_install_folder
+    app_folder = deb_folder + deb_install_path
     
     #### generate package in build
     mkdir(debian_folder)
@@ -142,7 +142,7 @@ def _create_deb_file(conanfile):
     ## generate deb package in build
     build_package_cmd = "dpkg-deb --build " + deb_folder + " " + deb_file
     conanfile.run(build_package_cmd)
-
+    
     ## copy *.deb in package folder to deb folder
     conanfile.copy(deb_file, dst=".", keep_path=False)
     output.success("copy deb_file '%s' to deb folder" % deb_file)
